#!/bin/bash -x
#
# Federated installation script

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin
trap cleanup `seq 0 15`

cleanup() {
   kill -9 $SPINPID &> /dev/null
   exit 2
}
spin() {
  spinner="/|\\-/|\\-"
  while :
  do
    for i in `seq 0 7`
    do
      echo -n "${spinner:$i:1}"
      echo -en "\010"
      sleep 1
    done
  done
}
fail() {
  echo -ne "FAILED\n\n$1\n\n"
  kill -9 $SPINPID &> /dev/null
#  [ -d "apps/dns" ] && rm -rf apps/dns
#  docker network rm fstack &> /dev/null
  exit 2;
}
failcheck() {
  echo -ne "\n\nFAILED - $1\n\n"
  exit 2;
}
get_config() {
  FSTACKURL="http://137.184.95.3:8000"
  [ ! -d "/federated/lib" ] && mkdir -p /federated/lib

  # Download each library file
  for i in checks network dns ldap mail; do
    if [ ! -f "/federated/lib/$i.sh" ]; then
      curl $FSTACKURL/$i.sh -o /federated/lib/$i.sh -s -f &> /dev/null
      [ $? -ne 0 ] && failcheck "Couldn't download $i.sh"
    fi
  done

  . /federated/lib/checks.sh
  . /federated/lib/network.sh
  . /federated/lib/dns.sh
  . /federated/lib/postgresql.sh
  . /federated/lib/ldap.sh
  . /federated/lib/mail.sh
  . /federated/lib/collabora.sh
  . /federated/lib/nextcloud.sh
  . /federated/lib/matrix.sh
  . /federated/lib/jitsi.sh
  . /federated/lib/listmonk.sh
  . /federated/lib/vaultwarden.sh
  . /federated/lib/panel.sh
  . /federated/lib/proxy.sh

  echo -ne "\nFederated Stack install script\n\n"
  read -p '* Enter domain name (domain.com): ' DOMAIN
  read -p '* Enter company name (Domain Company): ' COMPANY
  read -sp '* Enter admin password to use for initial login: ' ADMINPASS
  [ -z "$DOMAIN" ] && failcheck "Must enter a domain name"
  [ -z "$COMPANY" ] && failcheck "Must enter a company name"
  [ -z "$ADMINPASS" ] && failcheck "Must enter a admin password"
}

while getopts d OPTION; do
  case "$OPTION" in
    d) DEBUG=ON;;
  esac
done

# Download lib scripts and take in setup variables
get_config

echo -ne "\n\nStarting Federated install for $DOMAIN\n"

# Check that we have docker installed.  Check that
# we have all ports available and not in use
check_docker
check_ports

# Configure docker private network
config_network

# Configure and start each federated service
for i in dns postgresql ldap mail collabora nextcloud matrix listmonk vaultwarden panel proxy jitsi; do
	config_$i
	start_$i
done

# Print out fstack environment details
echo -ne "\n\nInstall completed successfully.\n\n" 
echo -ne "Certificates at apps/dns/data/etc/letsencrypt/archive/$DOMAIN\n"
echo -ne "Webmail is at http://www.$DOMAIN:9002\n"
echo -ne "Login user: admin Password: Provided at start\n"
